﻿using System.ComponentModel;
using System.Linq;
using System.Collections.ObjectModel;

namespace AddNewItemInCombo
{
	public class ComboBoxModel : INotifyPropertyChanged
	{
		public event PropertyChangedEventHandler PropertyChanged;

		private string text;

		public ComboBoxModel()
		{
			this.Items = new ObservableCollection<DataItem>();
			this.InitializeItems();
		}

		private void InitializeItems()
		{
			// You could get the items from the database
			this.Items.Add(new DataItem("item 1"));
            this.Items.Add(new DataItem("item 2"));
            this.Items.Add(new DataItem("item 3"));
            this.Items.Add(new DataItem("item 4"));
		}

        public string Text
        {
            get
            {
                return this.text;
            }
            set
            {
                if (this.text != value)
                {
                    this.text = value;
                    this.OnPropertyChanged("Text");
                }
            }
        }

		public ObservableCollection<DataItem> Items { get; private set; }

		private void OnPropertyChanged(string propertyName)
		{
			if (this.PropertyChanged != null)
			{
				this.PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
			}
		}

		public void AddCurrentText()
		{
			if (!this.Items.Any(d => d.Text == this.Text))
			{
				// You could save the new item to the database
				this.Items.Add(new DataItem(this.Text));
			}
		}

		public void DeleteCurrentText()
		{
            var item = this.Items.FirstOrDefault(d => d.Text == this.Text);
            if (item != null)
            {
				// You could save the new item to the database
				this.Items.Remove(item);
			}
		}
	}

    public class DataItem
    {
        public DataItem(string text)
        {
            this.Text = text;
        }

        public string Text { get; set; }
    }
}